<?php

namespace Drupal\uib_common_ui\Config;

use Drupal\Core\Cache\CacheableMetadata;
use Drupal\Core\Config\ConfigFactoryOverrideInterface;
use Drupal\Core\Config\StorageInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;

/**
 * Provides configuration overrides for the uib_common_ui module.
 */
class ConfigUibOverride implements ConfigFactoryOverrideInterface {

  /**
   * The module handler service.
   *
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  protected $moduleHandler;

  /**
   * Constructs a ConfigUibOverride object.
   *
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module handler service.
   */
  public function __construct(ModuleHandlerInterface $module_handler) {
    $this->moduleHandler = $module_handler;
  }

  /**
   * {@inheritDoc}
   */
  public function loadOverrides($names): array {
    if (in_array('gin_login.settings', $names, TRUE)) {
      $module_path = $this->moduleHandler->getModule('uib_common_ui')->getPath();
      $logo_path = $module_path . '/public/image/uib_login_logo.svg';
      $overrides['gin_login.settings']['logo'] = ['path' => $logo_path];
    }

    return $overrides ?? [];
  }

  /**
   * {@inheritDoc}
   */
  public function getCacheSuffix(): string {
    return '';
  }

  /**
   * {@inheritDoc}
   */
  public function createConfigObject($name, $collection = StorageInterface::DEFAULT_COLLECTION): void {
  }

  /**
   * {@inheritDoc}
   */
  public function getCacheableMetadata($name) {
    return new CacheableMetadata();
  }

}
